@@ -7,18 +7,11 @@
 
 #include "abstractpropertyparser.h"
 
-#include <DOcr>
-
-DOCR_USE_NAMESPACE
-
 class ImagePropertyParser : public AbstractPropertyParser
 {
 public:
     explicit ImagePropertyParser(QObject *parent = nullptr);
     virtual QList<Property> properties(const QString &file) override;
-
-private:
-    DOcr ocr;
 };
 
 #endif   //IMAGEPROPERTYPARSER_H
